# takes as argument an associative array mapping some time interval
# (need not be of length one week) to the quantity purchased in that 
# interval. Returns average consumption, average inventory and max inventory.

sub ANALYSE_TIMELINE {
    local(%timeline) = @_;
    local (@weeks) = sort(keys(%timeline));
    local($firstweek, $lastweek) = ($weeks[0], $weeks[$#weeks]);
    local($week, $previous_week, $numweeks)=(0,$firstweek, 0);
    local($tot_consumption, $ave_consumption) = (0,0);
    local($tot_inventory, $ave_inventory, $max_inventory, $inventory)
	=(0,0,0,0);
    local($interpc_time, $sum_interpc_time, $sum_interpc_time_sq) = (0,0,0);
    local($ave_interpc_time, $var_interpc_time) = (0,0);
    local(@result);
    $numweeks = ($lastweek - $firstweek + 1);
    
    foreach $week (@weeks)
    {
	$tot_consumption += $timeline{$week};
	$interpc_time = $week - $previous_week;
	$sum_interpc_time += $interpc_time;
	$sum_interpc_time_sq += $interpc_time**2;
	$previous_week = $week;
    }
    $ave_consumption = $tot_consumption/$numweeks;
    for ($week=$firstweek; $week <= $lastweek; $week++)
    {
	$inventory = &MAX(($inventory + $timeline{$week} - $ave_consumption), 
			 0);
	$tot_inventory += $inventory;
	$max_inventory = &MAX($inventory, $max_inventory);
    }
    $ave_inventory = $tot_inventory/$numweeks;
    if ($numweeks > 1) {
	$ave_interpc_time = $sum_interpc_time/$#weeks;
	$var_interpc_time = $sum_interpc_time_sq/$#weeks
	    - ($ave_interpc_time)**2;
	$var_interpc_time  = sqrt($var_interpc_time);
    }

    @result = ($ave_consumption, $ave_inventory, $max_inventory,
	       $ave_interpc_time, $var_interpc_time);
    @result;
}
